trusted-signing-cli 0.2.0

A simple CLI tool to sign files with Trusted Signing
trusted-signing-cli-0.2.0 is not a library.

Trusted Signing CLI

A simple CLI tool to sign files with Trusted Signing

Prerequisites

Installation

cargo install trusted-signing-cli

Usage

The CLI expects the following environment variables to be set or you can pass them as arguments (you can use this article to get the credentials):

  • AZURE_CLIENT_ID
  • AZURE_CLIENT_SECRET
  • AZURE_TENANT_ID

Signing a single file: trusted-signing-cli -e <url> -a <account name> -c <certificate profile name> file1.exe

Signing multiple files: trusted-signing-cli -e <url> -a <account name> -c <certificate profile name> file1.exe file2.exe file3.exe

For more information run trusted-signing-cli --help